@@ -1,12 +1,12 @@
-use futures::io::AsyncWriteExt as _;
+use futures_lite::io::AsyncWriteExt as _;
 
 /// Writes ttyrec frames to a [`futures::io::AsyncWrite`] instance.
-pub struct Writer<T: futures::io::AsyncWrite> {
+pub struct Writer<T: futures_lite::io::AsyncWrite> {
     output: T,
     creator: crate::Creator,
 }
 
-impl<T: futures::io::AsyncWrite + std::marker::Unpin + Send> Writer<T> {
+impl<T: futures_lite::io::AsyncWrite + std::marker::Unpin + Send> Writer<T> {
     /// Creates a new [`Writer`](Self) from a [`futures::io::AsyncWrite`]
     /// instance.
     pub fn new(output: T) -> Self {
